@@ -99,6 +99,16 @@ class SQLPickle(object):
         kwargs['detect_types'] = detect_types
         self._conn = sqlite3.connect(**kwargs)
 
+    def _sanitise_table_name(self, v):
+        """
+        """
+        unsafe_chars = ";?/\'\""
+        for c in unsafe_chars:
+            if c in v:
+                raise ValueError("unsafe char :%s: in table name :%s:" % (c, v))
+        return v
+
+
     def open(self, database = ':memory:', table_name = 'key_values'):
         """open() opens the database in memory.
            open(filename) opens the database at the given filename.
@@ -107,7 +117,7 @@ class SQLPickle(object):
                uses the given table name.
         """
 
-        self._table_name = table_name
+        self._table_name = self._sanitise_table_name(table_name)
         self._database = database
         self._thread_id = _get_thread_id()
 
@@ -213,6 +223,16 @@ class SQLPickle(object):
         return ((deserialise(row['key']), deserialise(row['value'])) for row in rows)
 
 
+    def values(self):
+        """ values() returns a generator of values.
+        """
+        self._check_connection()
+        q = "select * from %s" % self._table_name
+        rows = self._cursor.execute(q).fetchall()
+        return (deserialise(row['value']) for row in rows)
+
+
+
     def pop(self, key, default = None):
         """ D.pop(k[,d]) -> v, remove specified key and return the corresponding value.
             If key is not found, d is returned if given, otherwise KeyError is raised
