@@ -95,6 +95,7 @@ class TestSQLPickle(unittest.TestCase):
         p.save('rtyu', 2)
         self.assertEqual(list(p.keys()), ['asdf', 'rtyu'])
         self.assertEqual(list(p.items()), [('asdf', 'qwer'), ('rtyu', 2)])
+        self.assertEqual(list(p.values()), ['qwer', 2])
 
 
 
@@ -152,6 +153,13 @@ class TestSQLPickle(unittest.TestCase):
         p._no_unicode_strings = True
         self.assertEquals(repr(p), repr({"asdf":"qwer", "rtyu":2}))
 
+    def test_unsafe_table_name(self):
+        """ does it raise an error on a bad table name?
+        """
+        
+        self.assertRaises(ValueError, sqlitepickle.SQLPickle, ":memory:", 'unsafe;insert into table blabla values bla;')
+
+
     def xxtest_time(self):
         f = tempfile.NamedTemporaryFile()
         fname = f.name
